"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.processConfigSet = void 0;
const core_1 = require("@takomo/core");
const command_path_1 = require("./command-path");
/**
 * @hidden
 */
const processConfigSet = async (holder, group, target, configSet, timer, state) => {
    const { io, ctx } = holder;
    io.info(`Execute config set: ${configSet.name}`);
    const stacksConfigRepository = await ctx.configRepository.createStacksConfigRepository(configSet.name, configSet.legacy);
    const results = new Array();
    for (const commandPath of configSet.commandPaths) {
        const commandPathTimer = timer.startChild(commandPath);
        const result = await command_path_1.processCommandPath(holder, group, target, configSet, commandPath, commandPathTimer, state, stacksConfigRepository);
        commandPathTimer.stop();
        results.push(result);
        if (!result.success) {
            state.failed = true;
        }
    }
    timer.stop();
    return {
        ...core_1.resolveCommandOutputBase(results),
        results,
        configSetName: configSet.name,
        timer,
    };
};
exports.processConfigSet = processConfigSet;
//# sourceMappingURL=config-set.js.map