"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.processDeploymentGroup = void 0;
const core_1 = require("@takomo/core");
const cockatiel_1 = require("cockatiel");
const deployment_target_1 = require("./deployment-target");
const convertToOperation = (holder, group, timer, state, target, results, policy, listener) => () => policy.execute(async () => {
    await listener.onTargetBegin();
    const result = await deployment_target_1.processDeploymentTarget(holder, group, target, timer.startChild(target.name), state);
    results.push(result);
    await listener.onTargetComplete();
    return result;
});
/**
 * @hidden
 */
const processDeploymentGroup = async (holder, group, timer, state) => {
    const { io, listener, input: { concurrentTargets }, } = holder;
    io.info(`Execute deployment group: ${group.path}`);
    const results = new Array();
    const deploymentPolicy = cockatiel_1.Policy.bulkhead(concurrentTargets, 10000);
    const operations = group.targets.map((target) => convertToOperation(holder, group, timer, state, target, results, deploymentPolicy, listener));
    await Promise.all(operations.map((o) => o()));
    timer.stop();
    return {
        ...core_1.resolveCommandOutputBase(results),
        results,
        path: group.path,
        timer,
    };
};
exports.processDeploymentGroup = processDeploymentGroup;
//# sourceMappingURL=deployment-group.js.map